<img src="http://mypy-lang.org/static/mypy_light.svg" alt="mypy logo" width="300px"/>

[![PyPI version](https://badge.fury.io/py/mobase-stubs.svg)](https://badge.fury.io/py/mobase-stubs)
[![mypy checked](https://camo.githubusercontent.com/34b3a249cd6502d0a521ab2f42c8830b7cfd03fa/687474703a2f2f7777772e6d7970792d6c616e672e6f72672f7374617469632f6d7970795f62616467652e737667)](http://mypy-lang.org/)

# Mypy stubs for the mobase Python API

This repository holds the stubs of the `mobase` python module, which contains the Python plugin
interface for [Mod Organizer 2](https://github.com/modorganizer2/modorganizer) plugins.
It uses the stub files that are produced by https://github.com/ModOrganizer2/pystubs-generation/.

# Installation

Simply install `mobase-stubs` with pip:

    $ pip install mobase-stubs
